/*
 * Copyright (C) 2008 Chris Ball <cjb@laptop.org>
 *
 * Licensed under the GNU Lesser General Public License Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <gmodule.h>
#include <glib.h>
#include <string.h>
#include <stdio.h>
#include <glib/gstdio.h>
#include <glib/gprintf.h>
#include <ohm-plugin.h>

/**
 * plugin_initalize:
 * @plugin: This class instance
 *
 * Read and set the initial state of the plugin.
 * We can assume all the required modules have been loaded, although it's
 * dangerous to assume the key values are anything other than the defaults.
 */
static void
plugin_initalize (OhmPlugin *plugin)
{
	FILE *fp;
	gchar profile[1024];
	
	g_debug("in %s", G_STRFUNC);

	/* read sugar profile entries, and set_key */	
	fp = g_fopen("/home/olpc/.sugar/default/config", "r");
	if (!fp) {
		g_debug ("Couldn't open /home/olpc/.sugar/default/config");
		return;
	}

	while (fgets(profile, sizeof(profile), fp) != NULL) {
		/* We get one iteration per line. */
		if (g_ascii_strncasecmp(profile,
					"automaticpm = True", 18) == 0) {
			ohm_plugin_conf_set_key (plugin,
						 "suspend.automatic_pm", 1);
		}
		else if (g_ascii_strncasecmp(profile,
					"automaticpm = False", 19) == 0) {
			ohm_plugin_conf_set_key (plugin,
						 "suspend.automatic_pm", 0);
		}
		else if (g_ascii_strncasecmp(profile,
					"extremepm = True", 16) == 0) {
			ohm_plugin_conf_set_key (plugin,
						 "suspend.extreme_pm", 1);
		}
		else if (g_ascii_strncasecmp(profile,
					"extremepm = False", 17) == 0) {
			ohm_plugin_conf_set_key (plugin,
						 "suspend.extreme_pm", 0);
		}
	}

	fclose(fp);
}

OHM_PLUGIN_DESCRIPTION (
	"OHM Sugar profile reader",	/* description */
	"0.0.1",			/* version */
	"cjb@laptop.org",		/* author */
	OHM_LICENSE_LGPL,		/* license */
	plugin_initalize,		/* initalize */
	NULL,				/* destroy */
	NULL				/* notify */
);

OHM_PLUGIN_PROVIDES (
	"button.lid",
	"button.power",
	"button.tablet"
);
